@@ -2,6 +2,19 @@ from decimal import Decimal
 import json
 
 
+# During debugging, this helps with the RipplePrimitive __getattr__
+# problem, described further down below.
+#class property(property):
+#    def __get__(self, obj, cls):
+#        try:
+#            return super(property, self).__get__(obj, cls)
+#        except AttributeError, e:
+#            import traceback
+#            traceback.print_exc()
+#            import sys
+#            sys.exit(1)
+
+
 class RipplePrimitive(dict):
     """Dict that allows attribute access."""
 
@@ -11,11 +24,21 @@ class RipplePrimitive(dict):
     def __getattr__(self, item):
         try:
             value = self[item]
+            # Convert nested dicts into RipplePrimitives on the fly on access
             if isinstance(value, dict) and not isinstance(value, RipplePrimitive):
                 value = RipplePrimitive(value)
                 self[item] = value
             return value
         except KeyError:
+            # XXX: This keeps hiding real AttributeErrors that occur during
+            # handling of a @property; if property "foo" somehow triggers
+            # an AttributeError, this will be called and will expose the
+            # exception we raise here instead of the original one. See also
+            # discussed here amongst other places:
+            # http://stackoverflow.com/questions/15401180/using-getattr-and-meeting-expected-behaviour-for-subclasses
+            # (see also the related Python bug report).
+            # One possible way to fix this might be implementing
+            # __getattribute__ instead and check if a property exists.
             raise AttributeError(item)
 
     def __repr__(self):
@@ -125,6 +148,10 @@ class AccountRootEntry(RipplePrimitive):
     """
 
     def affects_account(self, account):
+        if not 'Account' in self:
+            # A transactions AffectedNodes can contain an AccountRoot
+            # node entry without fields, so account for this.
+            return False
         return self.Account == account
 
 
@@ -165,12 +192,12 @@ class NodeModification(RipplePrimitive):
     def __init__(self, data):
         RipplePrimitive.__init__(self, data)
         node_class = LedgerEntries[data['LedgerEntryType']]
-        self.new = node_class(data['FinalFields'])
+        self.new = node_class(data.get('FinalFields', {}))
         if 'PreviousFields' in data:
             self.old = node_class(
                 # PreviousFields only contains parts, presumably those
                 # that changed, so add a fallback to the shared data).
-                shadow(data['PreviousFields'], data['FinalFields']))
+                shadow(data['PreviousFields'], data.get('FinalFields', {})))
         else:
             self.old = None
         self.type = type(self.new)
@@ -190,6 +217,7 @@ class NodeCreation(NodeModification):
         self.old = None
         self.type = type(self.new)
 
+
 class NodeDeletion(NodeModification):
     """An entry in the ``AffectedNodes`` key of a processed transaction.
     """
@@ -285,7 +313,10 @@ class first(object):
         if len(multiple) > 1:
             raise ValueError('More than one issuer on recipient side, '
                              'use the multi-value access property')
-        return multiple[0][1]
+        elif len(multiple) == 0:
+            return None
+        else:
+            return multiple[0][1]
 
 
 class PaymentTransaction(Transaction):
@@ -424,13 +455,10 @@ class PaymentTransaction(Transaction):
 
             [('rvYAfWj5gh67oV6fW32ZzP3Aw4Eubs59B', Decimal('500'))]
         """
-        if self.is_xrp_received:
-            return []
-        else:
-            nodes = self._get_nodes(account=self.Account, type=RippleStateEntry)
-            return tupledict(
-                [(node.counter_party(self.Account),
-                 node.new.trust_limit(self.Account)) for node in nodes])
+        nodes = self._get_nodes(account=self.Account, type=RippleStateEntry)
+        return tupledict(
+            [(node.counter_party(self.Account),
+             node.new.trust_limit(self.Account)) for node in nodes])
 
     # If there is only one issuer being received, make access easier.
     # These raise an exception when more than one issuer is involved.
